@@ -212,10 +212,10 @@ class ResourcesApp(object):
 
         try:
             stream = resource_stream(modname, relative_path)
-            ct, enc  = mimetypes.guess_type(os.path.basename(relative_path))
+            ct, enc = mimetypes.guess_type(os.path.basename(relative_path))
             # XXX: hardcoded for now, I want this to become different
             # at some point. Or not.
-            if ct == "application/javascript":
+            if ct in ('application/javascript', 'application/x-javascript', 'text/javascript'):
                 stream = _JavascriptFileIter(modname, relative_path, require_once, stream, self.bufsize)
             else:
                 stream = _FileIter(stream, self.bufsize)
